translate.filters.spelling

Package translate :: Package filters :: Module spelling |
[hide private]
[frames] | no frames]

# Source Code for Module translate.filters.spelling

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """An API to provide spell checking for use in checks or elsewhere."""
    23
    24  import sys
    25
    26  available = False
    27
    28  try:
    29      # Enchant
    30      from enchant import checker, DictNotFoundError, Error as EnchantError
    31      available = True
    32      checkers = {}
    33 -    def check(text, lang):
    34          if not lang in checkers:
    35              try:
    36                  checkers[lang] = checker.SpellChecker(lang)
    37                  # some versions only report an error when checking something
    38                  checkers[lang].check(u'bla')
    39              except EnchantError, e:
    40                  # sometimes this is raised instead of DictNotFoundError
    41                  print >> sys.stderr, str(e)
    42                  checkers[lang] = None
    43
    44          if not checkers[lang]:
    45              return
    46          spellchecker = checkers[lang]
    47          spellchecker.set_text(unicode(text))
    48          for err in spellchecker:
    49              yield err.word, err.wordpos, err.suggest()
    50
    51  except ImportError:
    52 -    def check(text, lang):
    53          return []
    54